Welcome to Pywr's documentation!
================================

Pywr is a generalised network resource allocation model written in Python. It intends to be fast, free and extendible.





Contents:

.. toctree::
   :maxdepth: 2

   install.rst
   tutorial.rst
   formulation.rst
   json.rst
   Cookbook <cookbook/cookbook.rst>
   Extending Pywr <extending_pywr/index.rst>
   Python API reference <api/pywr.rst>
   license.rst
